@@ -8,13 +8,14 @@ and check for matches.
 from dataclasses import dataclass
 from enum import Enum
 from functools import cache
-from typing import List
+from typing import List, Optional
 
 from tabulate import tabulate
 from yellowdog_client.model import (
     DoubleRange,
     Node,
     NodeSearch,
+    NodeStatus,
     TaskGroup,
     WorkerPool,
     WorkRequirement,
@@ -38,8 +39,8 @@ UNKNOWN_STRING = "NOT YET KNOWN"
 class MatchType(Enum):
     YES = "YES"  # Definite match to the worker pool (so far)
     NO = "NO"  # Definite non-match to the worker pool
-    MAYBE = "MAYBE (no Nodes have registered yet)"  # Possible match to the worker pool; no nodes yet
-    PARTIAL = "PARTIAL (at least one Node matches, but not all)"  # Some nodes in the worker pool match
+    MAYBE = "MAYBE (no Nodes available)"  # Possible match to the worker pool; no nodes available
+    PARTIAL = "PARTIAL (one or more Nodes match, but not all)"  # Some nodes in the worker pool match
 
 
 @dataclass
@@ -48,6 +49,8 @@ class PropertyMatch:
     task_group_values: str
     worker_pool_values: str
     match: MatchType
+    match_count: Optional[int] = None
+    total_nodes: Optional[int] = None
 
 
 class MatchReport:
@@ -151,7 +154,14 @@ class MatchReport:
                     p.property_name,
                     p.task_group_values,
                     p.worker_pool_values,
-                    p.match.value,
+                    (
+                        f"{p.match.value}"
+                        + (
+                            f" ({p.match_count}/{p.total_nodes})"
+                            if p.match_count is not None
+                            else ""
+                        )
+                    ),
                 ]
             )
 
@@ -217,7 +227,7 @@ class WorkerPools:
                 else ", ".join(task_group.runSpecification.workerTags)
             ),
             worker_pool_values=(
-                NONE_STRING
+                EMPTY_STRING
                 if worker_pool.properties.workerTag is None
                 else worker_pool.properties.workerTag
             ),
@@ -248,7 +258,7 @@ class WorkerPools:
             if node.details.instanceType != ""
         }
         worker_pool_values = (
-            UNKNOWN_STRING
+            EMPTY_STRING
             if len(nodes) == 0
             else (
                 ", ".join(node_instance_types)
@@ -258,12 +268,12 @@ class WorkerPools:
         )
 
         # Calculate match
+        matching_nodes_counter = 0
         if len(runspec_instance_types) == 0:
             match_type = MatchType.YES
         elif len(nodes) == 0:
             match_type = MatchType.MAYBE
         else:
-            matching_nodes_counter = 0
             for node in nodes:
                 if node.details.instanceType in runspec_instance_types:
                     matching_nodes_counter += 1
@@ -277,12 +287,16 @@ class WorkerPools:
         return PropertyMatch(
             property_name="Instance Type(s)",
             task_group_values=(
-                NONE_STRING
+                EMPTY_STRING
                 if task_group.runSpecification.instanceTypes is None
                 else ", ".join(task_group.runSpecification.instanceTypes)
             ),
             worker_pool_values=worker_pool_values,
             match=match_type,
+            match_count=(
+                matching_nodes_counter if len(runspec_instance_types) > 0 else None
+            ),
+            total_nodes=len(nodes) if len(runspec_instance_types) > 0 else None,
         )
 
     def _match_task_types(
@@ -311,10 +325,10 @@ class WorkerPools:
         )
 
         # Calculate match
+        matching_node_counter = 0
         if len(nodes) == 0:
             match_type = MatchType.MAYBE
         else:
-            matching_node_counter = 0
             for node in nodes:
                 if runspec_task_types <= set(node.details.supportedTaskTypes):
                     matching_node_counter += 1
@@ -334,6 +348,8 @@ class WorkerPools:
             ),
             worker_pool_values=worker_pool_values,
             match=match_type,
+            match_count=matching_node_counter,
+            total_nodes=len(nodes),
         )
 
     def _match_providers(
@@ -348,12 +364,12 @@ class WorkerPools:
         node_providers = {node.details.provider.value for node in nodes}
 
         # Calculate match
+        matching_node_counter = 0
         if len(runspec_providers) == 0:
             match_type = MatchType.YES
         elif len(nodes) == 0:
             match_type = MatchType.MAYBE
         else:
-            matching_node_counter = 0
             for node in nodes:
                 if node.details.provider in runspec_providers:
                     matching_node_counter += 1
@@ -367,7 +383,7 @@ class WorkerPools:
         return PropertyMatch(
             property_name="Provider(s)",
             task_group_values=(
-                NONE_STRING
+                EMPTY_STRING
                 if task_group.runSpecification.providers is None
                 else ", ".join([x.value for x in task_group.runSpecification.providers])
             ),
@@ -375,12 +391,14 @@ class WorkerPools:
                 UNKNOWN_STRING
                 if len(nodes) == 0
                 else (
-                    NONE_STRING
+                    EMPTY_STRING
                     if len(node_providers) == 0
                     else ", ".join(node_providers)
                 )
             ),
             match=match_type,
+            match_count=matching_node_counter if len(runspec_providers) > 0 else None,
+            total_nodes=len(nodes) if len(runspec_providers) > 0 else None,
         )
 
     def _match_regions(
@@ -397,12 +415,12 @@ class WorkerPools:
         }
 
         # Calculate match
+        matching_node_counter = 0
         if len(runspec_regions) == 0:
             match_type = MatchType.YES
         elif len(nodes) == 0:
             match_type = MatchType.MAYBE
         else:
-            matching_node_counter = 0
             for node in nodes:
                 if node.details.region in runspec_regions:
                     matching_node_counter += 1
@@ -416,16 +434,18 @@ class WorkerPools:
         return PropertyMatch(
             property_name="Region(s)",
             task_group_values=(
-                NONE_STRING
+                EMPTY_STRING
                 if task_group.runSpecification.regions is None
                 else ", ".join(task_group.runSpecification.regions)
             ),
             worker_pool_values=(
-                UNKNOWN_STRING
+                EMPTY_STRING
                 if len(nodes) == 0
                 else ", ".join(node_regions) if len(node_regions) > 0 else NONE_STRING
             ),
             match=match_type,
+            match_count=matching_node_counter if len(runspec_regions) > 0 else None,
+            total_nodes=len(nodes) if len(runspec_regions) > 0 else None,
         )
 
     @staticmethod
@@ -435,12 +455,12 @@ class WorkerPools:
         return PropertyMatch(
             property_name="Namespace(s)",
             task_group_values=(
-                NONE_STRING
+                EMPTY_STRING
                 if task_group.runSpecification.namespaces is None
                 else ", ".join(task_group.runSpecification.namespaces)
             ),
             worker_pool_values=(
-                NONE_STRING if worker_pool.namespace is None else worker_pool.namespace
+                EMPTY_STRING if worker_pool.namespace is None else worker_pool.namespace
             ),
             match=(
                 MatchType.YES
@@ -458,12 +478,12 @@ class WorkerPools:
         nodes_ram = {node.details.ram for node in nodes}
 
         # Calculate match
+        matching_node_counter = 0
         if task_group.runSpecification.ram is None:
             match_type = MatchType.YES
         elif len(nodes) == 0:
             match_type = MatchType.MAYBE
         else:
-            matching_node_counter = 0
             for node in nodes:
                 if self._check_in_range(
                     node.details.ram, task_group.runSpecification.ram
@@ -489,6 +509,12 @@ class WorkerPools:
                 else ", ".join([str(node_ram) for node_ram in nodes_ram])
             ),
             match=match_type,
+            match_count=(
+                None
+                if task_group.runSpecification.ram is None
+                else matching_node_counter
+            ),
+            total_nodes=None if task_group.runSpecification.ram is None else len(nodes),
         )
 
     def _match_vcpus(
@@ -499,12 +525,12 @@ class WorkerPools:
         nodes_vcpus = {node.details.vcpus for node in nodes}
 
         # Calculate match
+        matching_node_counter = 0
         if task_group.runSpecification.vcpus is None:
             match_type = MatchType.YES
         elif len(nodes) == 0:
             match_type = MatchType.MAYBE
         else:
-            matching_node_counter = 0
             for node in nodes:
                 if self._check_in_range(
                     node.details.vcpus, task_group.runSpecification.vcpus
@@ -530,6 +556,14 @@ class WorkerPools:
                 else ", ".join([str(node_vcpus) for node_vcpus in nodes_vcpus])
             ),
             match=match_type,
+            match_count=(
+                None
+                if task_group.runSpecification.vcpus is None
+                else matching_node_counter
+            ),
+            total_nodes=(
+                None if task_group.runSpecification.vcpus is None else len(nodes)
+            ),
         )
 
     @staticmethod
@@ -551,9 +585,14 @@ class WorkerPools:
 
     def _get_all_nodes_in_worker_pool(self, worker_pool: WorkerPool) -> List[Node]:
         """
-        Return all nodes in the worker pool.
+        Return all nodes in the worker pool. Optionally restrict to running nodes only.
         """
-        return self._get_all_nodes_in_worker_pool_cached(worker_pool.id)
+        nodes = self._get_all_nodes_in_worker_pool_cached(worker_pool.id)
+        return (
+            [node for node in nodes if node.status == NodeStatus.RUNNING]
+            if ARGS_PARSER.running_nodes_only
+            else nodes
+        )
 
     @staticmethod
     @cache
@@ -684,6 +723,8 @@ def main():
             f"({work_requirement.id})",
             override_quiet=True,
         )
+        if ARGS_PARSER.running_nodes_only:
+            print_log("Comparing RUNNING nodes in the worker pool(s) only")
         for task_group in work_requirement.taskGroups:
             _compare_task_group(task_group, worker_pools)
 
